==> mingw-w64-i686-qt6-base-6.0.3-1-any.pkg.tar.zst: mingw32/lib/cmake/Qt6CoreTools/Qt6CoreToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::moc" for configuration "Release"
set_property(TARGET Qt6::moc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::moc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/moc.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::moc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::moc "${_IMPORT_PREFIX}/bin/moc.exe" )

# Import target "Qt6::rcc" for configuration "Release"
set_property(TARGET Qt6::rcc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::rcc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/rcc.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::rcc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::rcc "${_IMPORT_PREFIX}/bin/rcc.exe" )

# Import target "Qt6::tracegen" for configuration "Release"
set_property(TARGET Qt6::tracegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::tracegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/tracegen.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::tracegen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::tracegen "${_IMPORT_PREFIX}/bin/tracegen.exe" )

# Import target "Qt6::cmake_automoc_parser" for configuration "Release"
set_property(TARGET Qt6::cmake_automoc_parser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::cmake_automoc_parser PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/cmake_automoc_parser.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::cmake_automoc_parser )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::cmake_automoc_parser "${_IMPORT_PREFIX}/bin/cmake_automoc_parser.exe" )

# Import target "Qt6::qlalr" for configuration "Release"
set_property(TARGET Qt6::qlalr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qlalr PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qlalr.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qlalr )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qlalr "${_IMPORT_PREFIX}/bin/qlalr.exe" )

# Import target "Qt6::qmake" for configuration "Release"
set_property(TARGET Qt6::qmake APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmake PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmake.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmake )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmake "${_IMPORT_PREFIX}/bin/qmake.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-i686-qt6-base-6.1.2-1-any.pkg.tar.zst: mingw32/lib/cmake/Qt6CoreTools/Qt6CoreToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::moc" for configuration "Release"
set_property(TARGET Qt6::moc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::moc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/moc.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::moc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::moc "${_IMPORT_PREFIX}/share/qt6/bin/moc.exe" )

# Import target "Qt6::rcc" for configuration "Release"
set_property(TARGET Qt6::rcc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::rcc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/rcc.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::rcc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::rcc "${_IMPORT_PREFIX}/share/qt6/bin/rcc.exe" )

# Import target "Qt6::tracegen" for configuration "Release"
set_property(TARGET Qt6::tracegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::tracegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/tracegen.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::tracegen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::tracegen "${_IMPORT_PREFIX}/share/qt6/bin/tracegen.exe" )

# Import target "Qt6::cmake_automoc_parser" for configuration "Release"
set_property(TARGET Qt6::cmake_automoc_parser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::cmake_automoc_parser PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/cmake_automoc_parser.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::cmake_automoc_parser )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::cmake_automoc_parser "${_IMPORT_PREFIX}/share/qt6/bin/cmake_automoc_parser.exe" )

# Import target "Qt6::qlalr" for configuration "Release"
set_property(TARGET Qt6::qlalr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qlalr PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/qlalr.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qlalr )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qlalr "${_IMPORT_PREFIX}/share/qt6/bin/qlalr.exe" )

# Import target "Qt6::qmake" for configuration "Release"
set_property(TARGET Qt6::qmake APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmake PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmake.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmake )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmake "${_IMPORT_PREFIX}/bin/qmake.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
